@@ -155,3 +155,42 @@ def request_data(turb, start_date=None, end_date=None):
 
 
 
+def request_turbine_type(turb):
+    """
+    Loads the turbine type of an iSpin installation
+    
+    Parameters
+    --------------
+    turb : int
+        Turbine ID of the installation of interest (see "request_overview()")    
+    
+    Returns
+    ------------
+    type : str
+        Turbine type of the requested iSpin installation
+    """  
+    
+    import requests
+    
+    # start and end date format
+    if type(turb) != int:
+        raise Exception('Please set the turbine ID as an integer')
+
+    # Obtaining authentication token
+    authHeader = __authorize()
+    
+    # Requesting the turbines data
+    __baseUrl = "https://api.romowind.net/api"
+    URL = __baseUrl + '/turbines/' + str(turb) + '/details'
+    response = requests.get(URL, headers=authHeader, verify=False)
+    Dataresponse = response.json()
+    
+    # Error messages if the request fails
+    if 'message' in Dataresponse.keys():
+        if 'not found' in Dataresponse['message']:
+            raise Exception('The requested turbine was not found. Check that you have the right permissions to see data for this turbine')
+  
+    return Dataresponse['turbineTypeTitle']
+  
+  
+  
